{ config, lib, pkgs, ... }:

let
  unstable = import <nixos-unstable> { config.allowUnfree = true; };
  cloudstation = pkgs.callPackage (import ../packages/cloudstation.nix) { };
  nagstamon = pkgs.libsForQt5.callPackage (import ../packages/nagstamon.nix) { };
  myslack = pkgs.slack.overrideAttrs (oldAttrs: rec {
    fixupPhase = ''
      sed -i -e 's/,"WebRTCPipeWireCapturer"/,"LebRTCPipeWireCapturer"/' $out/lib/slack/resources/app.asar

      rm $out/bin/slack
      makeWrapper $out/lib/slack/slack $out/bin/slack \
        --prefix XDG_DATA_DIRS : $GSETTINGS_SCHEMAS_PATH \
        --suffix PATH : ${lib.makeBinPath [ pkgs.xdg-utils ]} \
        --add-flags "--ozone-platform-hint=auto --enable-features=WaylandWindowDecorations,WebRTCPipeWireCapturer"
    '';
  });
in {

  environment.variables = {
    USE_GKE_GCLOUD_AUTH_PLUGIN = "True";
  };

  services.tailscale = {
    enable = true;
    package = unstable.tailscale;
  };

  security.pki.certificateFiles = [
    ../dotfiles/certs/NetzmarktCA.crt
    ../dotfiles/certs/vcenter.netzmarkt.lan.crt
  ];

  networking.extraHosts = ''
    10.100.7.11 mon.netzmarkt.de
    85.10.233.162 live.bonedo.de

    172.20.0.2 hubble.kind
    172.20.0.2 dashboard.kind
    172.20.0.2 grafana.kind
    172.20.0.2 alert.kind

    #192.168.2.111 hass.home.f2o.io
    #192.168.2.111 sync.home.f2o.io
    192.168.2.111 pl.home.f2o.io

    #127.0.0.1 auth-dev.thobits.com
    127.0.0.1 database
    127.0.0.1 youtube.com
    127.0.0.1 www.youtube.com

    34.49.192.42 www.tbone.audio
    34.49.192.42 jobs.thomann.de

  '';

  environment.systemPackages = with pkgs; [
    (import ../packages/oc311.nix)
    (import ../packages/oc46.nix)
    (import ../packages/openshift-install-4.5.nix)
    # (import ../packages/vaultsink.nix) needs opensource verson
    cloudstation
    nagstamon
    yubikey-manager
    anydesk
    chromium
    nodejs
    vscodium

    drone-cli
    govc
    ttyd
    discord
    (google-cloud-sdk.withExtraComponents [
      google-cloud-sdk.components.gke-gcloud-auth-plugin
    ])
    myslack
    velero

    obs-studio
    obs-studio-plugins.wlrobs

    prusa-slicer
  ];

  # yubikey support
  services.udev.packages = [ pkgs.yubikey-personalization ];
  services.pcscd.enable = true;
}
